[Piglit] [PATCH 1/2] sample-mask-execution: fix misleading description

Chris Forbes chrisf at ijw.co.nz
Fri Nov 29 17:45:45 PST 2013


This has never rendered purple. Working correctly, it renders
half-intensity yellow.

Signed-off-by: Chris Forbes <chrisf at ijw.co.nz>
---
 tests/spec/arb_texture_multisample/sample-mask-execution.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/tests/spec/arb_texture_multisample/sample-mask-execution.c b/tests/spec/arb_texture_multisample/sample-mask-execution.c
index 7d2da44..2a6c2f8 100644
--- a/tests/spec/arb_texture_multisample/sample-mask-execution.c
+++ b/tests/spec/arb_texture_multisample/sample-mask-execution.c
@@ -37,7 +37,7 @@ PIGLIT_GL_TEST_CONFIG_END
  * - render a blue thing
  *
  * - blit from the MSAA buffer to the winsys buffer
  * - ensure that the pixels are purple
  */
 
 GLuint fbo, tex;
@@ -45,7 +45,7 @@ GLuint fbo, tex;
 enum piglit_result
 piglit_display(void)
 {
-    float half_purple[] = { 0.5f, 0.5f, 0.0f, 1.0f };
+    float half_yellow[] = { 0.5f, 0.5f, 0.0f, 1.0f };
     bool pass = true;
 
     glBindFramebuffer(GL_FRAMEBUFFER, fbo);
@@ -80,8 +80,8 @@ piglit_display(void)
     glBindFramebuffer(GL_READ_FRAMEBUFFER, piglit_winsys_fbo);
 
     /* the resolve done by the blit should
-     * blend the red and blue samples together */
-    pass = piglit_probe_pixel_rgba(32, 32, half_purple) && pass;
+     * blend the red and green samples together */
+    pass = piglit_probe_pixel_rgba(32, 32, half_yellow) && pass;
 
     piglit_present_results();
 
@@ -37,7 +37,7 @@ PIGLIT_GL_TEST_CONFIG_END
  *
  * - blit from the MSAA buffer to the winsys buffer
- * - ensure that the pixels are purple
+ * - ensure that the pixels are yellow
  */
 
-- 
1.8.4.2



More information about the Piglit mailing list